PyAMG is an open source project (see contributing.md) with
the following organizational structure:
- **Project Lead**: Luke Olson
- **Core developers**: Nathan Bell, Luke Olson, Jacob Schroder
- **Regular developers**: Luke Olson, Jacob Schroder, Ben Southworth

The project consists of the git repository, the wiki and accompanying
information associated with the repository (but not the organization), and the
releases.  All contributions should follow `CONTRIBUTING.md`. `DEVELOPERS.txt`
refers to core developers. 

#### Project Lead

- Final decisions rest with the project lead, including
  project design, unresolved issues and pull requests, and
  direction of the project, or any other items.

- The project lead determines the membership, the roles of developers,
  and the final authorship of the project.

- The project lead sets the coding standards, workflow, and release schedule for the project.

#### Core Developers:

- a.k.a. `DEVELOPERS.txt`

- Contributions transfer copyright to core developers, as in `DEVELOPERS.txt`

- The core developers are responsible for code reviews, identifying major
  contributions to the project, and proposing new directions for contributions.

#### Regular Developers:

- The regular developers contribute new features, major redesign of code, etc. to the
  project.

- The developers assist with issue handling and with reviews.

#### Contributors:

- See `CONTRIBUTING.md`

- Contributors may propose improvements to the project including (but
  not limited to) refactoring code, linting, bug fixes, documentation
  enhancements, example demos, and tests.

#### Authorship (aka The Citation):

- See `citation.bib`

- There is no automatic claim to authorship by contributing code to the project.
